<?php
/**
 * Metabox Whatsapp-Link
 */
class Metabox_Whatsapp_Link {

    public function __construct() {

        if ( is_admin() ) {
            add_action( 'load-post.php', array( $this, 'init_metabox' ) );
            add_action( 'load-post-new.php', array( $this, 'init_metabox' ) );
            add_action( 'admin_print_styles', array( $this, 'add_script_metabox') );
        }

    }

    // Inicializando metabox
    public function init_metabox() {

        add_action( 'add_meta_boxes', array( $this, 'add_metabox' ) );
        add_action( 'save_post', array( $this, 'save_metabox' ), 10, 2 );

    }

    // Habilitando a caixa metabox
    public function add_metabox() {

        // Habilitando o metabox apenas para os post_type que forem configurados no painel de configurações
        $post_type = get_option('whatsapp_post_type');

        if( $post_type ){

            add_meta_box(
                'whatsapp_custom_number_meta_id',
                'Whatsapp Número Personalizado',
                array( $this, 'whatsapp_custom_number_meta' ),
                $post_type, // array( 'page', 'post' )
                'normal',
                'high'
            );

        }

    }

    // Script para ser carregado pelo metabox
    public function add_script_metabox(){
        wp_enqueue_script( 'mask', WL_URL .'admin/js/jquery.mask.min.js', array('jquery'), '1.0', true );
    }

    // Html para o metabox
    public function whatsapp_custom_number_meta( $post ) {

        // Criando nonce
        wp_nonce_field( 'whatsapp_nonce_action', 'whatsapp_nonce' );

        $whatsapp_number_popup   = get_post_meta( $post->ID, 'whatsapp_number_popup', true );
        $whatsapp_popup_mensagem = get_post_meta( $post->ID, 'whatsapp_popup_mensagem', true ); ?>

        <table class="form-table">
            <tr>
                <td colspan="2">
                    <span class="description">As opções não configuradas aqui irão usar as configurações do <a href="<?php echo esc_url( get_admin_url( '', 'options-general.php?page=whatsapp-config.php') ); ?>" target="_blank">painel do plugin</a></span>
                </td>
            </tr>
            <tr>
                <th>
                    <label for="whatsapp_number_popup">Número do whatsapp</label>
                </th>
                <td>
                    <input type="text" data-mask="+99 (99) 999999999" id="whatsapp_number_popup" name="whatsapp_number_popup" value="<?php echo esc_attr(get_post_meta( $post->ID, 'whatsapp_number_popup', true ) ); ?>">
                </td>
            </tr>
            <tr>
                <th>
                    <label for="whatsapp_user_mensagem">Mensagem pré-definida</label>
                </th>
                <td>
                    <input type="text" id="whatsapp_user_mensagem" name="whatsapp_user_mensagem" class="large-text" value="<?php echo esc_attr( strip_tags( get_post_meta( $post->ID, 'whatsapp_user_mensagem', true ) ) ); ?>">
                    <span class="description">Essa mensagem será pré-carregada ao abrir o whatsapp.</span>
                </td>
            </tr>
            <tr>
                <th>
                    <label for="whatsapp_mensagem_largura">Largura da mensagem flutuante</label>
                </th>
                <td>
                    <input type="text" style="max-width: 55px;" id="whatsapp_mensagem_largura" name="whatsapp_mensagem_largura" class="regular-text" value="<?php echo esc_attr( get_post_meta( $post->ID, 'whatsapp_mensagem_largura', true ) ); ?>" placeholder="280px">
                    <span class="description">Deixe em branco para usar a configuração padrão.</span>
                </td>
            </tr>
            <tr>
                <th scope="row"><label for="whatsapp_animation">Animação</label></th>
                <td>
                    <?php $current = get_post_meta( $post->ID, 'whatsapp_animation', true ); ?>
                    <select id="whatsapp_animation" class="regular-text2" name="whatsapp_animation">
                        <option value="">Configuração Padrão</option>
                        <option value="whatsapp-pulse-button"<?php selected( $current, 'whatsapp-pulse-button', true); ?>>Pulse</option>
                        <option value="whatsapp-focus-button"<?php selected( $current, 'whatsapp-focus-button', true); ?>>Focus</option>
                        <option value="whatsapp-satelite-button"<?php selected( $current, 'whatsapp-satelite-button', true); ?>>Satélite</option>
                        <option value="whatsapp-fantasma-button"<?php selected( $current, 'whatsapp-fantasma-button', true); ?>>Fantasma</option>
                        <option value="whatsapp-treme-treme-button"<?php selected( $current, 'whatsapp-treme-treme-button', true); ?>>Treme Treme</option>
                        <option value="whatsapp-multcolor-button"<?php selected( $current, 'whatsapp-multcolor-button', true); ?>>Multicolor</option>
                    </select>
                </td>
            </tr>
            <tr>
                <th>
                    <label for="whatsapp_popup_mensagem">Mensagem flutuante</label>
                </th>
                <td>
                    <?php $mensagem = get_post_meta( $post->ID, 'whatsapp_popup_mensagem', true ); ?>
                    <textarea id="whatsapp_popup_mensagem" name="whatsapp_popup_mensagem" class="large-text" rows="5" cols="30"><?php echo stripslashes( $mensagem ); ?></textarea>
                    <p class="description">Se deseja usar uma pequena imagem ao lado da mensagem use o padrão <code style="display:inline-block;">&lt;img src=&quot;&quot; alt=&quot;&quot;&gt;&lt;p&gt;Seu texto&lt;/p&gt;</code></p>
                </td>
            </tr>
        </table><?php

    }

    // Salvando os campos criados pelo metabox
    public function save_metabox( $post_id, $post ) {

        // Verificando nonce
        $nonce_name   = isset( $_POST['whatsapp_nonce'] ) ? $_POST['whatsapp_nonce'] : '';
        $nonce_action = 'whatsapp_nonce_action';

        // Se não existe o nonce para aqui
        if ( ! isset( $nonce_name ) )
            return;

        // Checa se o nonce é válido
        if ( ! wp_verify_nonce( $nonce_name, $nonce_action ) )
            return;

        // Verificando se o usuário tem permissão para editar o post
        if ( ! current_user_can( 'edit_post', $post_id ) )
            return;

        // Verifique se não é um autosave.
        if ( wp_is_post_autosave( $post_id ) )
            return;

        // Verifica se não é um post revisão
        if ( wp_is_post_revision( $post_id ) )
            return;

        // Sanitize campos input salvos pelo usuário
        $whatsapp_number_popup     = isset( $_POST[ 'whatsapp_number_popup' ] ) ? sanitize_text_field( $_POST['whatsapp_number_popup'] ) : '';
        $whatsapp_mensagem_largura = isset( $_POST[ 'whatsapp_mensagem_largura' ] ) ? sanitize_text_field( $_POST['whatsapp_mensagem_largura'] ) : '';
        $whatsapp_animation        = isset( $_POST[ 'whatsapp_animation' ] ) ? sanitize_text_field( $_POST['whatsapp_animation'] ) : '';
        $whatsapp_popup_mensagem   = isset( $_POST[ 'whatsapp_popup_mensagem' ] ) ? addslashes( stripslashes( $_POST['whatsapp_popup_mensagem'] ) ) : '';
        $whatsapp_user_mensagem    = isset( $_POST[ 'whatsapp_user_mensagem' ] ) ? esc_attr( strip_tags( $_POST['whatsapp_user_mensagem'] ) ) : '';

        // Atualizando o campo meta no banco de dados
        if( $whatsapp_number_popup ){
            update_post_meta( $post_id, 'whatsapp_number_popup', $whatsapp_number_popup );
        } else {
            delete_post_meta( $post_id, 'whatsapp_number_popup' );
        }

        if( $whatsapp_popup_mensagem ){
            update_post_meta( $post_id, 'whatsapp_popup_mensagem', $whatsapp_popup_mensagem );
        } else {
            delete_post_meta( $post_id, 'whatsapp_popup_mensagem' );
        }

        if( $whatsapp_user_mensagem ){
            update_post_meta( $post_id, 'whatsapp_user_mensagem', $whatsapp_user_mensagem );
        } else {
            delete_post_meta( $post_id, 'whatsapp_user_mensagem' );
        }

        if( $whatsapp_mensagem_largura ){
            update_post_meta( $post_id, 'whatsapp_mensagem_largura', $whatsapp_mensagem_largura );
        } else {
            delete_post_meta( $post_id, 'whatsapp_mensagem_largura' );
        }

        if( $whatsapp_animation ){
            update_post_meta( $post_id, 'whatsapp_animation', $whatsapp_animation );
        } else {
            delete_post_meta( $post_id, 'whatsapp_animation' );
        }

    }

}
// Inicializando a class Metabox_Whatsapp_Link
new Metabox_Whatsapp_Link;
